@@ -14,6 +14,10 @@ wpi::array<int, 4> load_array_int(wpi::array<int, 4> data) {
     return data;
 }
 
+wpi::array<int, 1> load_array_int1(wpi::array<int, 1> data) {
+    return data;
+}
+
 /*
 span Tests
 */
@@ -29,6 +33,10 @@ wpi::span<std::string> load_span_string(wpi::span<std::string> ref) {
     return ref;
 }
 
+wpi::span<const std::string> load_span_string_const(wpi::span<const std::string> ref) {
+    return ref;
+}
+
 wpi::span<std::string_view> load_span_string_view(wpi::span<std::string_view> ref) {
     return ref;
 }
@@ -42,6 +50,23 @@ wpi::span<int> cast_span() {
     return vec;
 }
 
+wpi::span<const std::string> make_string_span() {
+    static std::vector<std::string> vec{"hi", "there"};
+    return vec;
+}
+
+py::object cast_string_span() {
+    return py::cast(make_string_span());
+}
+
+wpi::span<const uint8_t> load_span_bytes(wpi::span<const uint8_t> ref) {
+    return ref;
+}
+
+void modify_span_buffer(wpi::span<uint8_t> ref) {
+    ref[0] = 0x4;
+}
+
 /*
 SmallSet tests
 */
@@ -88,13 +113,18 @@ RPYBUILD_PYBIND11_MODULE(m) {
 
     // array
     m.def("load_array_int", &load_array_int);
+    m.def("load_array_int1", &load_array_int1);
     // span
     m.def("load_span_int", &load_span_int);
     m.def("load_span_bool", &load_span_bool);
     m.def("load_span_string", &load_span_string);
+    m.def("load_span_string_const", &load_span_string_const);
     m.def("load_span_string_view", &load_span_string_view);
     m.def("load_span_vector", &load_span_vector);
     m.def("cast_span", &cast_span);
+    m.def("cast_string_span", &cast_string_span);
+    m.def("load_span_bytes", &load_span_bytes);
+    m.def("modify_span_buffer", &modify_span_buffer);
     // SmallSet
     m.def("load_smallset_int", &load_smallset_int);
     m.def("cast_smallset", &cast_smallset);
